interface Price {
    price: number;
    label: string | null;
}
interface Rating {
    score: number | null;
    outOf: number | null;
}
/**
 * @class AmazonSearchResult
 * @description An object containing common properties that can be scraped from different Amazon search result
 * formats.
 * @public
 * @property {string} title - Name of product
 * @property {string} productUrl - URL for product details page
 * @property {string} imageUrl - lead product image that shows in search results
 * @property {Array.<Rating>} rating - Score out of a total value
 * @property {Array.<Price>} prices - Search often lists multiple prices for versions of an item. This is a set of all
 * found prices, some of which have labels attached (for example, if you search a DVD barcode number, there are multiple
 * prices, for DVD, Blu-ray and 4K, and each has a label like "4K"). Price label is null if cannot find it on page
 * @property {boolean} sponsored - whether result is an ad
 */
export default class AmazonSearchResult {
    private static domain;
    title: string;
    productUrl: string;
    imageUrl: string;
    rating: Rating;
    prices: Price[];
    sponsored: boolean;
    private static extractIsSponsored;
    private static extractPrices;
    private static extractRating;
    constructor(block: Element);
    get fullProductUrl(): string;
    set fullProductUrl(productUrl: string);
}
export {};
//# sourceMappingURL=amazon-search-result.d.ts.map